from django.conf import settings
from django.utils.importlib import import_module

try:
    from django.utils.module_loading import import_string
except ImportError:
    def import_string(value):
        module_name, func_name = value.rsplit('.', 1)
        module = import_module(module_name)
        return getattr(module, func_name)


def create_report():
    report = {}

    checks = _get_registered_health_checks()
    for service, func_string in checks.iteritems():
        check_func = import_string(func_string)
        report[service] = check_func() or False
    return report


def create_service_result(service):
    func_string = _get_registered_health_checks().get(service)
    if not func_string:
        return

    check_func = import_string(func_string)
    return check_func() or False


def _get_registered_health_checks():
    return getattr(settings, 'HEALTH_CHECKS', {})



from django.db import connection


def check_database():
    """Check if the application can perform a dummy sql query"""
    cursor = connection.cursor()
    cursor.execute('SELECT 1; -- Healthcheck')
    row = cursor.fetchone()
    return row[0] == 1


def check_dummy_true():
    return True


def check_dummy_false():
    return False



from django.http import JsonResponse, HttpResponse
from django.http.response import Http404
from django.views.generic import View

from django_healthchecks.checker import create_report, create_service_result


class HealthCheckView(View):
    def get(self, request, *args, **kwargs):
        report = create_report()
        return JsonResponse(report)


class HealthCheckServiceView(View):
    def get(self, request, service, *args, **kwargs):
        result = create_service_result(service)
        if result is None:
            raise Http404()

        if result:
            return HttpResponse('true')
        return HttpResponse('false', status=500)



from setuptools import find_packages, setup


with open('README.rst', 'r') as fh:
    description = '\n'.join(fh.readlines())

tests_require = [
    'pytest>=2.6.0',
    'pytest-cov>=1.7.0',
    'pytest-django>=2.8.0',
]

setup(
    name='django-healthchecks',
    version='0.1.0',
    description=description,
    url='https://github.com/mvantellingen/django-healthchecks',
    author="Michael van Tellingen",
    author_email="michaelvantellingen@gmail.com",
    install_requires=[
        'Django>=1.7',
    ],
    tests_require=tests_require,
    extras_require={'test': tests_require},
    entry_points={
    },
    package_dir={'': 'src'},
    packages=find_packages('src'),
    include_package_data=True,
    license='MIT',
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: MIT License',
    ],
    zip_safe=False,
)
